@@ -3,7 +3,7 @@ use strict;
 
 use CPANPLUS::inc;
 use CPANPLUS::Internals::Constants;
-use CPANPLUS::Error                 qw[error msg];
+use CPANPLUS::Error;
 
 use Log::Message;
 use Module::Load                qw[load];
@@ -251,6 +251,8 @@ sub save {
     my $time = gmtime;
 
     load Data::Dumper;
+    local $Data::Dumper::Sortkeys = 1; 
+    
     my $data = Data::Dumper->Dump([$self->conf], ['conf']);
 
     ## get rid of the bless'ing
@@ -467,7 +469,7 @@ sub AUTOLOAD {
     my $conf = $self->conf;
 
     unless( scalar @_ ) {
-        error loc("No arguments provided!");
+        error( loc("No arguments provided!") );
         return;
     }
 
@@ -482,7 +484,7 @@ sub AUTOLOAD {
     $type .= $field if $field;
 
     unless ( exists $conf->{$type} ) {
-        error loc("Invalid method type: '%1'", $name);
+        error( loc("Invalid method type: '%1'", $name) );
         return;
     }
 
@@ -501,7 +503,7 @@ sub AUTOLOAD {
                 return $self->get_conf($key);  
                 
             } else {     
-                error loc(q[No such key '%1' in field '%2'], $key, $type);
+                error( loc(q[No such key '%1' in field '%2'], $key, $type) );
                 return;
             }
 
@@ -518,7 +520,7 @@ sub AUTOLOAD {
                 $conf->{$type}->{$key} = $val;
 
             } else {
-                error loc(q[No such key '%1' in field '%2'], $key, $type);
+                error( loc(q[No such key '%1' in field '%2'], $key, $type) );
                 return;
             }
         }
@@ -542,7 +544,7 @@ sub AUTOLOAD {
         return 1;
     } else {
 
-        error loc(q[Unknown action '%1'], $action);
+        error( loc(q[Unknown action '%1'], $action) );
         return;
     }
 }
