@@ -280,7 +280,10 @@ sub prepare {
             ### one key value pair are passed as is, rather than as:
             ### perl Makefile.PL "key=val key=>val"
             my $captured; my $makefile_pl = MAKEFILE_PL->();
-            unless(scalar run(  command => "$perl $makefile_pl $mmflags",
+            
+            ### setting autoflush to true fixes issue from rt #8047
+            my $flush = OPT_AUTOFLUSH;
+            unless(scalar run(  command => "$perl $flush $makefile_pl $mmflags",
                                 buffer  => \$captured,
                                 verbose => $run_verbose, # may be interactive   
             ) ) {
@@ -376,10 +379,12 @@ sub _find_prereqs {
         last;
     }
 
-    $self->status->prereqs( \%p );
+    my $href = $cb->_callbacks->filter_prereqs->( $cb, \%p );
+
+    $self->status->prereqs( $href );
     
     ### just to make sure it's not the same reference ###
-    return { %p };                              
+    return { %$href };                              
 }     
 
 =pod
@@ -526,9 +531,7 @@ sub create {
             $dist->status->make(1);
 
             ### add this directory to your lib ###
-            $cb->_add_to_includepath(
-                directories => [ BLIB_LIBDIR->( $self->status->extract ) ]
-            );
+            $self->add_to_includepath();
             
             ### dont bail out here, there's a conditional later on
             #last RUN if $skiptest;
