@@ -86,7 +86,7 @@ use constant FILE_EXISTS    => sub {
                                     return 1 if IS_FILE->($file);
                                     local $Carp::CarpLevel = 
                                             $Carp::CarpLevel+2;
-                                    cp_error(loc(  q[File '%1' does not exist],
+                                    error(loc(  q[File '%1' does not exist],
                                                 $file));
                                     return;
                             };    
@@ -96,7 +96,7 @@ use constant FILE_READABLE  => sub {
                                     return 1 if -e $file && -r _;
                                     local $Carp::CarpLevel = 
                                             $Carp::CarpLevel+2;
-                                    cp_error( loc( q[File '%1' is not readable ].
+                                    error( loc( q[File '%1' is not readable ].
                                                 q[or does not exist], $file));
                                     return;
                             };    
@@ -107,7 +107,7 @@ use constant DIR_EXISTS     => sub {
                                     return 1 if IS_DIR->($dir);
                                     local $Carp::CarpLevel = 
                                             $Carp::CarpLevel+2;                                    
-                                    cp_error(loc(q[Dir '%1' does not exist],
+                                    error(loc(q[Dir '%1' does not exist],
                                             $dir));
                                     return;
                             };   
@@ -168,7 +168,7 @@ use constant OPEN_FILE      => sub {
                                     my($file, $mode) = (@_, '');
                                     my $fh;
                                     open $fh, "$mode" . $file
-                                        or cp_error(loc(
+                                        or error(loc(
                                             "Could not open file '%1': %2",
                                              $file, $!));
                                     return $fh if $fh;
