@@ -151,9 +151,12 @@ It would looks something like this:
 
 {
     my $map = {
+        ### used to have 0.80, but not it was never released by coral
+        ### 0.79 *should* be good enough for now... asked coral to 
+        ### release 0.80 on 10/3/2006
+        'IPC::Run'                  => '0.79', 
         'File::Fetch'               => '0.07',
         #'File::Spec'                => '0.82', # can't, need it ourselves...
-        'IPC::Run'                  => '0.80',
         'IPC::Cmd'                  => '0.24',
         'Locale::Maketext::Simple'  => 0,
         'Log::Message'              => 0,
@@ -167,6 +170,7 @@ It would looks something like this:
         'Object::Accessor'          => '0.03',
         'Module::CoreList'          => '1.97',
         'Module::Pluggable'         => '2.4',
+        'Module::Loaded'            => 0,
         #'Config::Auto'             => 0,   # not yet, not using it yet
     };
 
@@ -380,7 +384,7 @@ find out exactly what C<CPANPLUS::inc> is doing.
             ### or otherwise, the one not bundled
             ### or otherwise the newest
             my @sorted = sort {
-                            vcmp($b->[0], $a->[0])                  ||
+                            _vcmp($b->[0], $a->[0])                  ||
                             ($Cache{$interesting}
                                 ?($b->[2] eq $Cache{$interesting}->[0][2]) <=>
                                  ($a->[2] eq $Cache{$interesting}->[0][2])
@@ -395,7 +399,7 @@ find out exactly what C<CPANPLUS::inc> is doing.
                     if $DEBUG;
 
             if( $check_version and 
-                not (vcmp($sorted[0][0], $map->{$module}) >= 0) 
+                not (_vcmp($sorted[0][0], $map->{$module}) >= 0) 
             ) {
                 warn __PACKAGE__ .": Cannot find high enough version for "
                                  ."'$module' -- need '$map->{$module}' but "
@@ -431,7 +435,8 @@ find out exactly what C<CPANPLUS::inc> is doing.
     }
 }
 
-sub vcmp {
+### XXX copied from C::I::Utils, so there's no circular require here!
+sub _vcmp {
     my ($x, $y) = @_;
     s/_//g foreach $x, $y;
     return $x <=> $y;
